# Copyright (c) 2000-2012, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%bcond_without mead
%define _jarsign_opts --copy=%{_javadir} --unsign=%{_javadir}

%if "%{?rhel}" == "6"
%if %with mead
%bcond_with repolib
%else
%bcond_without repolib
%endif
%else
%bcond_with repolib
%endif

%define reltag .redhat_2
%define namedreltag -redhat-2
%global namedversion %{version}%{?namedreltag}

%define section free

%define maven_version 201103-redhat-2

Name:           rngom
Version:        201103
Release:        0.5%{?reltag}%{?dist}.4
Epoch:          0
Summary:        RELAX NG Object Model / Parser
License:        MIT-style
Group:          Development/Java

%if %with mead
Source100: org.kohsuke.rngom-rngom-201103-redhat-2-sources.zip
Source101: org.kohsuke.rngom-rngom-201103-redhat-2-patches.zip
Source102: rngom-201103-redhat-2.pom
Source103: rngom-201103-redhat-2.jar
Source104: rngom-201103-redhat-2-javadoc.jar
Source105: rngom-201103-redhat-2-sources.jar
%endif

URL:            https://rngom.dev.java.net/
%if %without mead
%if 0
rm -rf rngom-201103.tar.bz2 rngom-201103
svn -q export -r '{20110406}' https://svn.java.net/svn/rngom~svn/trunk/rngom
tar cjf rngom-201103.tar.bz2 rngom
%endif
Source0:        rngom-201103.tar.bz2
Patch0:         rngom-vman.patch
%endif
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:       java >= 0:1.5.0
Requires:       jpackage-utils
Requires:       relaxngDatatype
%if %without mead
BuildRequires:  java-devel
BuildRequires:  jpackage-utils
BuildRequires:  maven2-plugin-antrun
BuildRequires:  maven2-plugin-clean
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-deploy
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven2-plugin-surefire
BuildRequires:  maven2-plugin-site
BuildRequires:  maven-surefire-provider-junit4
BuildRequires:  javacc-maven-plugin
BuildRequires:  jboss-parent
BuildRequires:  junit
BuildRequires:  xsdlib
BuildRequires:  relaxngDatatype
BuildRequires:  xmlunit
%endif
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
RNGOM is an open-source Java library for parsing RELAX NG 
grammars. In particular, RNGOM can:
1. parse the XML syntax
2. parse the compact syntax
3. check all the semantic restrictions as specified in the 
   specification
4. parse RELAX NG into application-defined data structures
5. build a default data structure based around the binarized 
   simple syntax or another data structure that preserves 
   more of the parsed information.
6. parse foreign elements/attributes in a schema
7. parse comments in a schema 

%if %without mead
%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

Requires:       jpackage-utils

%description javadoc
%{summary}.
%endif

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java


%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%if %without mead
%setup -q -n rngom
%patch0 -p1 -b .sav0
%endif

%build
%if %without mead
export MAVEN_REPO_LOCAL=`pwd`/.m2/repository
export ALT_DEPLOYMENT_REPOSITORY=oss-releases::default::file://`pwd`/maven2-brew
export MAVEN_OPTS="-Xms1g -Xmx1g"
%{_bindir}/mvn-jpp -e -Dmaven.repo.local=${MAVEN_REPO_LOCAL} -DaltDeploymentRepository=${ALT_DEPLOYMENT_REPOSITORY} -Dmaven.test.failure.ignore deploy javadoc:aggregate
%endif

%install
%{__rm} -rf %{buildroot}

# jars
%{__mkdir_p} %{buildroot}%{_javadir}
%if %without mead
%{__cp} -p maven2-brew/org/kohsuke/rngom/rngom/%{namedversion}/rngom-%{namedversion}-sources.jar %{buildroot}%{_javadir}/rngom-%{namedversion}-sources.jar
%{__cp} -p maven2-brew/org/kohsuke/rngom/rngom/%{namedversion}/rngom-%{namedversion}.jar %{buildroot}%{_javadir}/rngom-%{namedversion}.jar
%else
%{__cp} -p %{_sourcedir}/%{name}-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}-%{namedversion}.jar
%{__cp} -p %{_sourcedir}/%{name}-%{namedversion}-sources.jar %{buildroot}%{_javadir}/%{name}-%{namedversion}-sources.jar
%endif
(cd %{buildroot}%{_javadir} && for jar in *-%{namedversion}*; do %{__ln_s} ${jar} `/bin/echo ${jar} | %{__sed} -e "s|-%{namedversion}||g"`; done)

# poms
%{__mkdir_p} %{buildroot}%{_mavenpomdir}
%if %without mead
%{__cp} -p maven2-brew/org/kohsuke/rngom/rngom/%{namedversion}/rngom-%{namedversion}.pom %{buildroot}%{_mavenpomdir}/JPP-rngom.pom
%else
%{__cp} -p %{_sourcedir}/%{name}-%{namedversion}.pom %{buildroot}%{_datadir}/maven2/poms/JPP-rngom.pom
%endif

# depmaps
%add_to_maven_depmap org.kohsuke.rngom rngom %{namedversion} JPP rngom

# javadoc
%if %without mead
%{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{namedversion}
%{__cp} -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}-%{namedversion}
%{__ln_s} %{name}-%{namedversion} %{buildroot}%{_javadocdir}/%{name}
%endif

# repolib
%if %with repolib
%{__mkdir_p} %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew
%{__cp} -pr maven2-brew/* %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew
%endif

%clean
%{__rm} -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%{_javadir}*/rngom-%{namedversion}-sources.jar
%{_javadir}*/rngom-sources.jar
%{_javadir}*/rngom-%{namedversion}.jar
%{_javadir}*/rngom.jar
%{_mavenpomdir}/JPP-rngom.pom
%{_mavendepmapfragdir}/rngom

%if %without mead
%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{namedversion}
%{_javadocdir}/%{name}
%endif

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}*
%exclude %dir %{_javadocdir}
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Wed Sep 19 2012 Fernando Nasser <fnasser@redhat.com> - 0:201103-0.5.redhat_2.4
- Rebuild for MD5

* Mon Aug 20 2012 Vladimir Dosoudil <dosoudil@redhat.com> - 0:201103-0.4.redhat_2.4
- Update poms for eap 6.0.1

* Tue Aug 14 2012 Fernando Nasser <fnasser@redhat.com> - 0:201103-0.4.redhat_2.3
- Rebuild unsigned

* Thu Aug 09 2012 Fernando Nasser <fnasser@redhat.com> - 0:201103-0.4.redhat_2.2
- Rebuild unsigned

* Mon Jul 30 2012 Fernando Nasser <fnasser@redhat.com> - 0:201103-0.4.redhat_1.1
- Rebuild unsigned

* Thu Jul 05 2012 Martha Benitez <mbenitez@redhat.com> - 0:201103-0.4.redhat_1
- Build in MEAD

* Thu Jun 14 2012 David Walluck <dwalluck@redhat.com> 0:201103-0.3
- fix typo in BuildRoot definition

* Tue Mar 27 2012 David Walluck <dwalluck@redhat.com> 0:201103-0.2
- add repolib

* Wed Feb 22 2012 David Walluck <dwalluck@redhat.com> 0:201103-0.1
- 201103
- use maven to build

* Tue Mar 11 2008 Ralph Apel <r.apel at r-apel.de> 0:0.1-0.20061207.1jpp
- 20061207 == jaxb21_fcs tag
